@@ -182,8 +182,11 @@ QMap<QString, IonInterface::ConditionIcons> EnvCanadaIon::setupConditionIconMapp
         { QStringLiteral("snow crystals"), Flurries },
         { QStringLiteral("snow grains"), Flurries },
         { QStringLiteral("squalls"), Snow },
+        { QStringLiteral("thunderstorm"), Thunderstorm },
         { QStringLiteral("thunderstorm with hail"), Thunderstorm },
         { QStringLiteral("thunderstorm with rain"), Thunderstorm },
+        { QStringLiteral("thunderstorm with light rainshowers"), Thunderstorm },
+        { QStringLiteral("thunderstorm with heavy rainshowers"), Thunderstorm },
         { QStringLiteral("thunderstorm with sand or dust storm"), Thunderstorm },
         { QStringLiteral("thunderstorm without precipitation"), Thunderstorm },
         { QStringLiteral("tornado"), NotAvailable },
@@ -245,10 +248,10 @@ QMap<QString, IonInterface::ConditionIcons> EnvCanadaIon::setupForecastIconMappi
         { QStringLiteral("ice fog"), Mist },
         { QStringLiteral("ice fog developing"), Mist },
         { QStringLiteral("ice fog dissipating"), Mist },
-        { QStringLiteral("ice pellet"), Hail },
-        { QStringLiteral("ice pellet mixed with freezing rain"), Hail },
-        { QStringLiteral("ice pellet mixed with snow"), Hail },
-        { QStringLiteral("ice pellet or snow"), RainSnow },
+        { QStringLiteral("ice pellets"), Hail },
+        { QStringLiteral("ice pellets mixed with freezing rain"), Hail },
+        { QStringLiteral("ice pellets mixed with snow"), Hail },
+        { QStringLiteral("ice pellets or snow"), RainSnow },
         { QStringLiteral("light snow"), LightSnow },
         { QStringLiteral("light snow and blizzard"), LightSnow },
         { QStringLiteral("light snow and blizzard and blowing snow"), Snow },
@@ -280,18 +283,18 @@ QMap<QString, IonInterface::ConditionIcons> EnvCanadaIon::setupForecastIconMappi
         { QStringLiteral("periods of freezing rain or ice pellets"), FreezingRain },
         { QStringLiteral("periods of freezing rain or rain"), FreezingRain },
         { QStringLiteral("periods of freezing rain or snow"), FreezingRain },
-        { QStringLiteral("periods of ice pellet"), Hail },
-        { QStringLiteral("periods of ice pellet mixed with freezing rain"), Hail },
-        { QStringLiteral("periods of ice pellet mixed with snow"), Hail },
-        { QStringLiteral("periods of ice pellet or freezing rain"), Hail },
-        { QStringLiteral("periods of ice pellet or snow"), Hail },
+        { QStringLiteral("periods of ice pellets"), Hail },
+        { QStringLiteral("periods of ice pellets mixed with freezing rain"), Hail },
+        { QStringLiteral("periods of ice pellets mixed with snow"), Hail },
+        { QStringLiteral("periods of ice pellets or freezing rain"), Hail },
+        { QStringLiteral("periods of ice pellets or snow"), Hail },
         { QStringLiteral("periods of light snow"), LightSnow },
         { QStringLiteral("periods of light snow and blizzard"), Snow },
         { QStringLiteral("periods of light snow and blizzard and blowing snow"), Snow },
         { QStringLiteral("periods of light snow and blowing snow"), LightSnow },
         { QStringLiteral("periods of light snow mixed with freezing drizzle"), RainSnow },
         { QStringLiteral("periods of light snow mixed with freezing rain"), RainSnow },
-        { QStringLiteral("periods of light snow mixed with ice pelletS"), LightSnow },
+        { QStringLiteral("periods of light snow mixed with ice pellets"), LightSnow },
         { QStringLiteral("periods of light snow mixed with rain"), RainSnow },
         { QStringLiteral("periods of light snow or freezing drizzle"), RainSnow },
         { QStringLiteral("periods of light snow or freezing rain"), RainSnow },
@@ -739,7 +742,8 @@ bool EnvCanadaIon::readXMLData(const QString& source, QXmlStreamReader& xml)
             (data.observationDateTime.isValid() &&
             (!qIsNaN(data.stationLatitude) && !qIsNaN(data.stationLongitude)));
         if (canCalculateElevation) {
-            data.solarDataTimeEngineSourceName = QStringLiteral("Local|Solar|Latitude=%1|Longitude=%2|DateTime=%3")
+            data.solarDataTimeEngineSourceName = QStringLiteral("%1|Solar|Latitude=%2|Longitude=%3|DateTime=%4")
+                .arg(QString::fromUtf8(data.observationDateTime.timeZone().id()))
                 .arg(data.stationLatitude)
                 .arg(data.stationLongitude)
                 .arg(data.observationDateTime.toString(Qt::ISODate));
@@ -947,7 +951,7 @@ void EnvCanadaIon::parseConditions(WeatherData& data, QXmlStreamReader& xml)
             } else if (elementName == QLatin1String("dateTime")) {
                 parseDateTime(data, xml);
             } else if (elementName == QLatin1String("condition")) {
-                data.condition = xml.readElementText();
+                data.condition = xml.readElementText().trimmed();
             } else if (elementName == QLatin1String("temperature")) {
                 // prevent N/A text to result in 0.0 value
                 parseFloat(data.temperature, xml);
