@@ -48,6 +48,7 @@ namespace KNS3 {
 }
 
 class BackgroundListModel;
+class SlideModel;
 
 class Image : public QObject, public QQmlParserStatus
 {
@@ -57,11 +58,13 @@ class Image : public QObject, public QQmlParserStatus
     Q_PROPERTY(RenderingMode renderingMode READ renderingMode WRITE setRenderingMode NOTIFY renderingModeChanged)
     Q_PROPERTY(QUrl wallpaperPath READ wallpaperPath NOTIFY wallpaperPathChanged)
     Q_PROPERTY(QAbstractItemModel *wallpaperModel READ wallpaperModel CONSTANT)
+    Q_PROPERTY(QAbstractItemModel *slideshowModel READ slideshowModel CONSTANT)
     Q_PROPERTY(int slideTimer READ slideTimer WRITE setSlideTimer NOTIFY slideTimerChanged)
     Q_PROPERTY(QStringList usersWallpapers READ usersWallpapers WRITE setUsersWallpapers NOTIFY usersWallpapersChanged)
     Q_PROPERTY(QStringList slidePaths READ slidePaths WRITE setSlidePaths NOTIFY slidePathsChanged)
     Q_PROPERTY(QSize targetSize READ targetSize WRITE setTargetSize NOTIFY targetSizeChanged)
     Q_PROPERTY(QString photosPath READ photosPath CONSTANT)
+    Q_PROPERTY(QStringList uncheckedSlides READ uncheckedSlides WRITE setUncheckedSlides NOTIFY uncheckedSlidesChanged)
 
     public:
 
@@ -82,6 +85,7 @@ class Image : public QObject, public QQmlParserStatus
 
         Q_INVOKABLE void addSlidePath(const QString &path);
         Q_INVOKABLE void removeSlidePath(const QString &path);
+        Q_INVOKABLE void openFolder(const QString& path);
 
         Q_INVOKABLE void getNewWallpaper(QQuickItem *ctx = nullptr);
         Q_INVOKABLE void showFileDialog();
@@ -89,6 +93,8 @@ class Image : public QObject, public QQmlParserStatus
         Q_INVOKABLE void addUsersWallpaper(const QString &file);
         Q_INVOKABLE void commitDeletion();
 
+        Q_INVOKABLE void toggleSlide(const QString &path, bool checked);
+
         RenderingMode renderingMode() const;
         void setRenderingMode(RenderingMode mode);
 
@@ -98,6 +104,7 @@ class Image : public QObject, public QQmlParserStatus
         KPackage::Package *package();
 
         QAbstractItemModel* wallpaperModel();
+        QAbstractItemModel* slideshowModel();
 
         int slideTimer() const;
         void setSlideTimer(int time);
@@ -116,7 +123,10 @@ class Image : public QObject, public QQmlParserStatus
 
         QString photosPath() const;
 
-    public Q_SLOTS:
+        QStringList uncheckedSlides() const;
+        void setUncheckedSlides(const QStringList &uncheckedSlides);
+
+        public Q_SLOTS:
         void nextSlide();
         void removeWallpaper(QString name);
 
@@ -130,6 +140,7 @@ class Image : public QObject, public QQmlParserStatus
         void slidePathsChanged();
         void resizeMethodChanged();
         void customWallpaperPicked(const QString &path);
+        void uncheckedSlidesChanged();
 
     protected Q_SLOTS:
         void showAddSlidePathsDialog();
@@ -175,9 +186,11 @@ class Image : public QObject, public QQmlParserStatus
         QStringList m_slideshowBackgrounds;
         QStringList m_unseenSlideshowBackgrounds;
         QStringList m_slidePaths;
+        QStringList m_uncheckedSlides;
         QTimer m_timer;
         int m_currentSlide;
         BackgroundListModel *m_model;
+        SlideModel* m_slideshowModel;
         QFileDialog *m_dialog;
         QString m_img;
         QDateTime m_previousModified;
